Re-exported from MOObject::extract_counts – view the MOObject docs for details.
Arguments
- moo
multiOmicDataSet containing
count_type&sub_count_typein the counts slot- count_type
the type of counts to use – must be a name in the counts slot (
moo@counts[[count_type]])- sub_count_type
if
count_typeis a list, specify the sub count type within the list (moo@counts[[count_type]][[sub_count_type]]). (Default:NULL)
See also
Other moo methods:
batch_correct_counts(),
calc_cpm(),
clean_raw_counts(),
diff_counts(),
filter_counts(),
filter_diff(),
normalize_counts(),
plot_corr_heatmap(),
plot_expr_heatmap(),
plot_histogram(),
plot_pca(),
plot_pca_2d(),
plot_pca_3d(),
plot_read_depth(),
plot_venn_diagram(),
plot_volcano_enhanced(),
plot_volcano_summary(),
run_deseq2(),
set_color_pal(),
set_default_colors()