Construct a multiOmicDataSet object from data frames
Source:R/0_mo-class.R
create_multiOmicDataSet_from_dataframes.RdWraps MOObject::create_multiOmicDataSet_from_dataframes() to add a "colors" analysis if it is not already present.
Usage
create_multiOmicDataSet_from_dataframes(
sample_metadata,
counts_dat,
sample_id_colname = NULL,
feature_id_colname = NULL,
count_type = "raw"
)Arguments
- sample_metadata
sample metadata as a data frame or tibble. The first column is assumed to contain the sample IDs which must correspond to column names in the raw counts.
- counts_dat
data frame of feature counts (e.g. expected feature counts from RSEM).
- sample_id_colname
name of the column in
sample_metadatathat contains the sample IDs. (Default:NULL- first column in the sample metadata will be used.)- feature_id_colname
name of the column in
counts_datthat contains feature/gene IDs. (Default:NULL- first column in the count data will be used.)- count_type
type to assign the values of
counts_datto in thecountsslot
Value
A MOObject::multiOmicDataSet object.