Construct a multiOmicDataSet object from text files (e.g. TSV, CSV).
Source:R/0_mo-class.R
create_multiOmicDataSet_from_files.RdWraps MOObject::create_multiOmicDataSet_from_files() to add a "colors" analysis if it is not already present.
Usage
create_multiOmicDataSet_from_files(
sample_meta_filepath,
feature_counts_filepath,
count_type = "raw",
sample_id_colname = NULL,
feature_id_colname = NULL,
delim = NULL,
...
)Arguments
- sample_meta_filepath
path to text file with sample IDs and metadata for differential analysis.
- feature_counts_filepath
path to text file of expected feature counts (e.g. gene counts from RSEM).
- count_type
type to assign the values of
counts_datto in thecountsslot- sample_id_colname
name of the column in
sample_metadatathat contains the sample IDs. (Default:NULL- first column in the sample metadata will be used.)- feature_id_colname
name of the column in
counts_datthat contains feature/gene IDs. (Default:NULL- first column in the count data will be used.)- delim
Delimiter used in the input files. Any delimiter accepted by
readr::read_delim()can be used. If the files are in CSV format, setdelim = ','; for TSV format, setdelim = '\t'.- ...
additional arguments forwarded to
readr::read_delim().
Value
A MOObject::multiOmicDataSet object.