Plot correlation heatmap for multiOmicDataSet
Source:R/plot_heatmap.R
plot_corr_heatmap-multiOmicDataSet.RdPlot correlation heatmap for multiOmicDataSet
Arguments
- moo_counts
a
multiOmicDataSetobject- count_type
the type of counts to use. Must be a name in the counts slot (
names(moo@counts)).- sub_count_type
used if
count_typeis a list in the counts slot: specify the sub count type within the list. Must be a name innames(moo@counts[[count_type]]).- group_colname
The column from the sample metadata containing the sample group information. This is usually a column showing to which experimental treatments each sample belongs (e.g. WildType, Knockout, Tumor, Normal, Before, After, etc.).
- color_values
vector of colors as hex values or names recognized by R. Unnamed colors are assigned by factor level order when the grouping column is a factor; otherwise, they are assigned in the order groups first appear in the metadata column. Defaults to
NULL; whenNULL,mosuite_paletteis used fordata.framedispatch and stored colors are used formultiOmicDataSetdispatch.- ...
additional arguments forwarded to
plot_corr_heatmap()fordata.frame
See also
plot_corr_heatmap() generic
Other plotters for multiOmicDataSets:
plot_histogram,MOSuite::multiOmicDataSet-method,
plot_pca,MOSuite::multiOmicDataSet-method,
plot_read_depth,MOSuite::multiOmicDataSet-method