Plot read depth for multiOmicDataSet
Source:R/plot_read_depth.R
plot_read_depth.multiOmicDataSet.RdPlot read depth for multiOmicDataSet
Arguments
- count_type
the type of counts to use. Must be a name in the counts slot (
names(moo@counts)).- sub_count_type
used if
count_typeis a list in the counts slot: specify the sub count type within the list. Must be a name innames(moo@counts[[count_type]]).- sample_id_colname
column in sample metadata containing sample IDs.
- group_colname
sample metadata column used to color bars. Leave blank to use the current single-color bar fill.
- color_values
colors used when
group_colnameis supplied. Named vectors are matched to group values; unnamed vectors follow group order and are extended with MOSuite colors when too few colors are supplied. Defaults toNULL; whenNULL,mosuite_paletteis used fordata.framedispatch and stored colors are used formultiOmicDataSetdispatch.
See also
plot_read_depth() generic
Other plotters for multiOmicDataSets:
plot_corr_heatmap,MOSuite::multiOmicDataSet-method,
plot_histogram,MOSuite::multiOmicDataSet-method,
plot_pca,MOSuite::multiOmicDataSet-method
Examples
# multiOmicDataSet
moo <- multiOmicDataSet(
sample_metadata = nidap_sample_metadata,
anno_dat = data.frame(),
counts_lst = list(
"raw" = nidap_raw_counts,
"clean" = nidap_clean_raw_counts
)
)
plot_read_depth(moo, count_type = "clean")